@@ -3,7 +3,6 @@
 
 #include <bluetooth-enums.h>
 #include "gnome-bluetooth-enum-types.h"
-#include "bluetooth-enums.h"
 #include <glib-object.h>
 
 /* enumerations from "bluetooth-enums.h" */
@@ -44,6 +43,7 @@ bluetooth_type_get_type (void)
       { BLUETOOTH_TYPE_PRINTER, "BLUETOOTH_TYPE_PRINTER", "printer" },
       { BLUETOOTH_TYPE_JOYPAD, "BLUETOOTH_TYPE_JOYPAD", "joypad" },
       { BLUETOOTH_TYPE_TABLET, "BLUETOOTH_TYPE_TABLET", "tablet" },
+      { BLUETOOTH_TYPE_VIDEO, "BLUETOOTH_TYPE_VIDEO", "video" },
       { 0, NULL, NULL }
     };
     etype = g_flags_register_static ("BluetoothType", values);
@@ -62,11 +62,11 @@ bluetooth_column_get_type (void)
       { BLUETOOTH_COLUMN_NAME, "BLUETOOTH_COLUMN_NAME", "name" },
       { BLUETOOTH_COLUMN_TYPE, "BLUETOOTH_COLUMN_TYPE", "type" },
       { BLUETOOTH_COLUMN_ICON, "BLUETOOTH_COLUMN_ICON", "icon" },
-      { BLUETOOTH_COLUMN_RSSI, "BLUETOOTH_COLUMN_RSSI", "rssi" },
       { BLUETOOTH_COLUMN_DEFAULT, "BLUETOOTH_COLUMN_DEFAULT", "default" },
       { BLUETOOTH_COLUMN_PAIRED, "BLUETOOTH_COLUMN_PAIRED", "paired" },
       { BLUETOOTH_COLUMN_TRUSTED, "BLUETOOTH_COLUMN_TRUSTED", "trusted" },
       { BLUETOOTH_COLUMN_CONNECTED, "BLUETOOTH_COLUMN_CONNECTED", "connected" },
+      { BLUETOOTH_COLUMN_DISCOVERABLE, "BLUETOOTH_COLUMN_DISCOVERABLE", "discoverable" },
       { BLUETOOTH_COLUMN_DISCOVERING, "BLUETOOTH_COLUMN_DISCOVERING", "discovering" },
       { BLUETOOTH_COLUMN_LEGACYPAIRING, "BLUETOOTH_COLUMN_LEGACYPAIRING", "legacypairing" },
       { BLUETOOTH_COLUMN_POWERED, "BLUETOOTH_COLUMN_POWERED", "powered" },
